@@ -6,12 +6,14 @@ Further Information might be available at:
 https://github.com/haypo/python-ipy
 """
 
-__version__ = '1.00'
+__version__ = '1.01'
 
 import bisect
-import collections
-import sys
 import types
+try:
+    import collections.abc as collections_abc
+except ImportError:
+    import collections as collections_abc
 
 # Definition of the Ranges for IPv4 IPs
 # this should include www.iana.org/assignments/ipv4-address-space
@@ -121,13 +123,14 @@ MAX_IPV6_ADDRESS = 0xffffffffffffffffffffffffffffffff
 IPV6_TEST_MAP    = 0xffffffffffffffffffffffff00000000
 IPV6_MAP_MASK    = 0x00000000000000000000ffff00000000
 
-if sys.version_info >= (3,):
+try:
+    INT_TYPES = (int, long)
+    STR_TYPES = (str, unicode)
+    xrange
+except NameError:
     INT_TYPES = (int,)
     STR_TYPES = (str,)
     xrange = range
-else:
-    INT_TYPES = (int, long)
-    STR_TYPES = (str, unicode)
 
 
 class IPint(object):
@@ -1029,10 +1032,10 @@ class IP(IPint):
         raise ValueError("%s cannot be converted to an IPv4 address."
                          % repr(self))
 
-class IPSet(collections.MutableSet):
+class IPSet(collections_abc.MutableSet):
     def __init__(self, iterable=[]):
         # Make sure it's iterable, otherwise wrap
-        if not isinstance(iterable, collections.Iterable):
+        if not isinstance(iterable, collections_abc.Iterable):
             raise TypeError("'%s' object is not iterable" % type(iterable).__name__)
         
         # Make sure we only accept IP objects
@@ -1106,7 +1109,7 @@ class IPSet(collections.MutableSet):
 
     def add(self, value):
         # Make sure it's iterable, otherwise wrap
-        if not isinstance(value, collections.Iterable):
+        if not isinstance(value, collections_abc.Iterable):
             value = [value]
         
         # Check type
@@ -1120,7 +1123,7 @@ class IPSet(collections.MutableSet):
     
     def discard(self, value):
         # Make sure it's iterable, otherwise wrap
-        if not isinstance(value, collections.Iterable):
+        if not isinstance(value, collections_abc.Iterable):
             value = [value]
             
         # This is much faster than iterating over the addresses
